@@ -945,13 +945,12 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-infra-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-infra-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-infra-secret/ca-bundle.crt'
 						type_name _doc
+                        http_backend typhoeus
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -989,14 +988,13 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-infra-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-infra-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-infra-secret/ca-bundle.crt'
 						type_name _doc
 						retry_tag retry_infra_es
+                        http_backend typhoeus
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -1036,13 +1034,12 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
 						type_name _doc
+                        http_backend typhoeus
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -1080,14 +1077,13 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
 						type_name _doc
 						retry_tag retry_apps_es_1
+                        http_backend typhoeus
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -1127,13 +1123,12 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-other-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-other-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-other-secret/ca-bundle.crt'
 						type_name _doc
+                        http_backend typhoeus
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -1171,14 +1166,13 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-other-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-other-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-other-secret/ca-bundle.crt'
 						type_name _doc
 						retry_tag retry_apps_es_2
+                        http_backend typhoeus
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -1218,13 +1212,12 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-audit-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-audit-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-audit-secret/ca-bundle.crt'
 						type_name _doc
+                        http_backend typhoeus
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -1262,14 +1255,13 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-audit-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-audit-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-audit-secret/ca-bundle.crt'
 						type_name _doc
 						retry_tag retry_audit_es
+                        http_backend typhoeus
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
