@@ -77,13 +77,12 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
 			remove_keys viaq_index_name
-			user fluentd
-			password changeme
 
 			client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 			client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 			ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
 			type_name _doc
+            http_backend typhoeus
 			write_operation create
 			reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 			# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -121,14 +120,13 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
 			remove_keys viaq_index_name
-			user fluentd
-			password changeme
 
 			client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 			client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 			ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
 			type_name _doc
 			retry_tag retry_oncluster_elasticsearch
+            http_backend typhoeus
 			write_operation create
 			reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 			# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -184,10 +182,9 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
 			remove_keys viaq_index_name
-			user fluentd
-			password changeme
 
 			type_name _doc
+            http_backend typhoeus
 			write_operation create
 			reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 			# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -224,11 +221,10 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
 			remove_keys viaq_index_name
-			user fluentd
-			password changeme
 
 			type_name _doc
 			retry_tag retry_other_elasticsearch
+            http_backend typhoeus
 			write_operation create
 			reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 			# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
