@@ -594,8 +594,6 @@ const storeElasticsearchTemplate = `{{ define "storeElasticsearch" -}}
   target_index_key viaq_index_name
   id_key viaq_msg_id
   remove_keys viaq_index_name
-  user fluentd
-  password changeme
 {{- if .Target.Secret }}
   client_key '{{ .SecretPath "tls.key"}}'
   client_cert '{{ .SecretPath "tls.crt"}}'
@@ -605,6 +603,7 @@ const storeElasticsearchTemplate = `{{ define "storeElasticsearch" -}}
 {{- if .Hints.Has "include_retry_tag" }}
   retry_tag {{.RetryTag}}
 {{- end }}
+  http_backend typhoeus
   write_operation create
   reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
   # https://github.com/uken/fluent-plugin-elasticsearch#reload-after
